"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const ern_core_1 = require("ern-core");
const getAssetsPath_1 = require("./getAssetsPath");
const fs_readdir_recursive_1 = __importDefault(require("fs-readdir-recursive"));
const path_1 = __importDefault(require("path"));
const fs_extra_1 = __importDefault(require("fs-extra"));
const semver_1 = __importDefault(require("semver"));
exports.supportedAssetsExts = ['.ttf', '.otf'];
/**
 * Copy in Container, the assets of all packages found in Composite,
 * that are exporting assets through react-native.config.js.
 * Similar to React Native, only fonts (.ttf/.otf) are supported for now.
 * This will copy the font assets of all packages that are either
 * dependencies:
 * https://github.com/react-native-community/cli/blob/master/docs/dependencies.md
 * or projects:
 * https://github.com/react-native-community/cli/blob/master/docs/projects.md
 */
async function copyRnConfigAssets({ compositePath, outDir, platform, }) {
    const pJson = await fs_extra_1.default.readJSON(path_1.default.join(compositePath, 'package.json'));
    const rnVersion = pJson.dependencies['react-native'];
    const dirs = await ern_core_1.findDirectoriesHavingRnConfig(compositePath);
    for (const dir of dirs) {
        const rnConfig = require(path_1.default.join(dir, 'react-native.config.js'));
        const assets = rnConfig.assets || (rnConfig.dependency && rnConfig.dependency.assets);
        if (assets) {
            if (platform === 'ios' && semver_1.default.gte(rnVersion, '0.61.0')) {
                const files = await fs_extra_1.default.readdir(dir);
                if (files.some((f) => f.endsWith('.podspec'))) {
                    ern_core_1.log.debug(`Skipping assets copy to container for ${dir} as it contains a podspec so the resources will be copied over by pod install`);
                    continue;
                }
            }
            for (const assetDir of assets) {
                const absDir = path_1.default.join(dir, assetDir);
                fs_readdir_recursive_1.default(absDir)
                    .filter((p) => {
                    return exports.supportedAssetsExts.includes(path_1.default.extname(p));
                })
                    .map((p) => path_1.default.join(assetDir, p))
                    .forEach((p) => {
                    ern_core_1.handleCopyDirective(dir, outDir, [
                        { source: p, dest: getAssetsPath_1.getAssetsPath(platform, 'fonts') },
                    ]);
                });
            }
        }
    }
}
exports.copyRnConfigAssets = copyRnConfigAssets;
//# sourceMappingURL=copyRnConfigAssets.js.map