"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const sortDependenciesByName_1 = require("./sortDependenciesByName");
const bundleMiniApps_1 = require("./bundleMiniApps");
const copyRnpmAssets_1 = require("./copyRnpmAssets");
const copyRnConfigAssets_1 = require("./copyRnConfigAssets");
const addContainerMetadata_1 = require("./addContainerMetadata");
const ern_core_1 = require("ern-core");
const fs_extra_1 = __importDefault(require("fs-extra"));
const path_1 = __importDefault(require("path"));
const lodash_1 = __importDefault(require("lodash"));
async function generateContainer(config, { fillContainerHull, postCopyRnpmAssets, postBundle, } = {}) {
    var _a;
    fs_extra_1.default.ensureDirSync(config.outDir);
    ern_core_1.shell.rm('-rf', path_1.default.join(config.outDir, '{.*,*}'));
    if (!config.plugins || config.plugins.length === 0) {
        config.plugins = await ern_core_1.kax
            .task('Resolving native dependencies')
            .run(config.composite.getInjectableNativeDependencies(config.targetPlatform));
    }
    config.plugins = sortDependenciesByName_1.sortDependenciesByName(config.plugins);
    const reactNativePlugin = lodash_1.default.find(config.plugins, (p) => p.name === 'react-native');
    // React-native plugin should be first in the dependencies
    // Otherwise any module dependent on r-n won't be able to use it
    config.plugins = [
        ...(reactNativePlugin ? [reactNativePlugin] : []),
        ...config.plugins.filter((plugin) => plugin !== reactNativePlugin),
    ];
    ern_core_1.shell.pushd(config.outDir);
    try {
        if (fillContainerHull) {
            await fillContainerHull(config);
        }
    }
    finally {
        ern_core_1.shell.popd();
    }
    const bundlingResult = await ern_core_1.kax
        .task('Bundling MiniApps')
        .run(bundleMiniApps_1.bundleMiniAppsFromComposite({
        compositeDir: config.composite.path,
        dev: !!config.devJsBundle,
        outDir: config.outDir,
        platform: config.targetPlatform,
        resetCache: config.resetCache,
        sourceMapOutput: config.sourceMapOutput,
    }));
    if (postBundle) {
        await postBundle(config, bundlingResult, (_a = reactNativePlugin) === null || _a === void 0 ? void 0 : _a.version);
    }
    const compositeMiniApps = await config.composite.getMiniApps();
    if (!config.ignoreRnpmAssets) {
        copyRnpmAssets_1.copyRnpmAssets(compositeMiniApps, config.composite.path, config.outDir, config.targetPlatform);
        await copyRnConfigAssets_1.copyRnConfigAssets({
            compositePath: config.composite.path,
            outDir: config.outDir,
            platform: config.targetPlatform,
        });
        if (postCopyRnpmAssets) {
            await postCopyRnpmAssets(config);
        }
    }
    await ern_core_1.kax
        .task('Adding Electrode Native Metadata File')
        .run(addContainerMetadata_1.addContainerMetadata(config));
    return {
        bundlingResult,
        config,
    };
}
exports.generateContainer = generateContainer;
//# sourceMappingURL=generateContainer.js.map