"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ern_core_1 = require("ern-core");
async function generatePluginsMustacheViews(plugins, platform) {
    const pluginsViews = [];
    ern_core_1.log.debug('Generating plugins mustache views');
    for (const plugin of plugins) {
        if (plugin.name === 'react-native') {
            continue;
        }
        let pluginConfig;
        if (platform === 'android') {
            pluginConfig = await ern_core_1.manifest.getPluginConfig(plugin, 'android');
        }
        else {
            pluginConfig = await ern_core_1.manifest.getPluginConfig(plugin, 'ios');
        }
        if (!pluginConfig) {
            ern_core_1.log.warn(`${plugin.name} does not have any injection configuration for ${platform} platform`);
            continue;
        }
        const pluginHook = pluginConfig.pluginHook;
        let containerHeader;
        if (platform === 'ios') {
            containerHeader = pluginConfig
                .containerPublicHeader;
        }
        if (!pluginHook && !containerHeader) {
            continue;
        }
        const pluginView = {};
        if (pluginHook) {
            pluginView.name = pluginHook.name;
            pluginView.lcname =
                pluginHook.name &&
                    pluginHook.name.charAt(0).toLowerCase() + pluginHook.name.slice(1);
            pluginView.configurable = pluginHook.configurable;
        }
        if (containerHeader) {
            pluginView.containerHeader = containerHeader;
        }
        pluginsViews.push(pluginView);
    }
    return pluginsViews;
}
exports.generatePluginsMustacheViews = generatePluginsMustacheViews;
//# sourceMappingURL=generatePluginsMustacheViews.js.map