"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const getContainerMetadataPath_1 = require("./getContainerMetadataPath");
const inferContainerPlatform_1 = require("./inferContainerPlatform");
const fs_extra_1 = __importDefault(require("fs-extra"));
/**
 * Get the native platform of a Container given its path.
 * The platform is retrieved from the Container metadata file if present.
 * If Container metadata is missing (ern < 0.17) or if the platform is missing
 * from the metadata (ern < 0.19.0) this function will fallback to infering
 * the Container platform
 * @param containerPath Local file system path to the Container
 */
function getContainerPlatform(containerPath) {
    if (!fs_extra_1.default.pathExistsSync(containerPath)) {
        throw new Error(`${containerPath} does not exist`);
    }
    const containerMetadataPath = getContainerMetadataPath_1.getContainerMetadataPath(containerPath);
    if (!fs_extra_1.default.pathExistsSync(containerMetadataPath)) {
        return inferContainerPlatform_1.inferContainerPlatform(containerPath);
    }
    const containerMetadataFile = fs_extra_1.default.readFileSync(containerMetadataPath);
    const containerMetadata = JSON.parse(containerMetadataFile.toString());
    if (!containerMetadata.platform) {
        return inferContainerPlatform_1.inferContainerPlatform(containerPath);
    }
    return containerMetadata.platform;
}
exports.getContainerPlatform = getContainerPlatform;
//# sourceMappingURL=getContainerPlatform.js.map