"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const ern_core_1 = require("ern-core");
const fs_extra_1 = __importDefault(require("fs-extra"));
const path_1 = __importDefault(require("path"));
async function reactNativeBundleIos({ bundleOutput, dev, outDir, sourceMapOutput, cwd, resetCache, }) {
    cwd = cwd || process.cwd();
    const miniAppOutPath = path_1.default.join(outDir, 'ElectrodeContainer', 'Libraries', 'MiniApp');
    bundleOutput = (bundleOutput !== null && bundleOutput !== void 0 ? bundleOutput : path_1.default.join(miniAppOutPath, 'MiniApp.jsbundle'));
    const assetsDest = miniAppOutPath;
    if (fs_extra_1.default.existsSync(assetsDest)) {
        ern_core_1.shell.rm('-rf', path_1.default.join(assetsDest, '{.*,*}'));
        ern_core_1.shell.mkdir('-p', path_1.default.join(assetsDest, 'assets'));
        // Write a dummy file to the empty `assets` directory,
        // otherwise empty directories are not pushed to git repositories
        // which will lead to issues when building the iOS Container
        // if the assets directory is missing
        fs_extra_1.default.writeFileSync(path_1.default.join(assetsDest, 'assets/README.md'), 'React Native bundled assets will be stored in this directory');
    }
    await fs_extra_1.default.ensureDir(miniAppOutPath);
    ern_core_1.shell.pushd(cwd);
    const entryFile = fs_extra_1.default.existsSync(path_1.default.join(cwd, 'index.ios.js'))
        ? 'index.ios.js'
        : 'index.js';
    try {
        const result = await ern_core_1.reactnative.bundle({
            assetsDest,
            bundleOutput,
            dev: !!dev,
            entryFile,
            platform: 'ios',
            resetCache,
            sourceMapOutput,
        });
        return result;
    }
    finally {
        ern_core_1.shell.popd();
    }
}
exports.reactNativeBundleIos = reactNativeBundleIos;
//# sourceMappingURL=reactNativeBundleIos.js.map